@@ -4,6 +4,7 @@ import copy
 
 import autoarray as aa
 
+from autoconf import conf
 from autoarray import exc
 from autoarray.dataset import abstract_dataset, preprocess
 from autoarray.structures import arrays, grids, visibilities as vis, kernel
@@ -15,13 +16,7 @@ logger = logging.getLogger(__name__)
 
 class AbstractInterferometer(abstract_dataset.AbstractDataset):
     def __init__(
-        self,
-        visibilities,
-        noise_map,
-        uv_wavelengths,
-        primary_beam=None,
-        positions=None,
-        name=None,
+        self, visibilities, noise_map, uv_wavelengths, positions=None, name=None
     ):
 
         super().__init__(
@@ -29,7 +24,6 @@ class AbstractInterferometer(abstract_dataset.AbstractDataset):
         )
 
         self.uv_wavelengths = uv_wavelengths
-        self.primary_beam = primary_beam
 
     @property
     def visibilities(self):
@@ -52,37 +46,128 @@ class AbstractInterferometer(abstract_dataset.AbstractDataset):
     def modified_visibilities_from_visibilities(self, visibilities):
 
         interferometer = copy.deepcopy(self)
-        interferometer.data = visibilities
+        interferometer.data = vis.Visibilities(visibilities_1d=visibilities)
         return interferometer
 
-    def resized_primary_beam_from_new_shape_2d(self, new_shape_2d):
+    def signal_to_noise_limited_from_signal_to_noise_limit(self, signal_to_noise_limit):
 
         interferometer = copy.deepcopy(self)
-        interferometer.primary_beam = self.primary_beam.resized_from_new_shape(
-            new_shape=new_shape_2d
+
+        noise_map_limit = np.where(
+            self.signal_to_noise_map > signal_to_noise_limit,
+            np.abs(self.visibilities) / signal_to_noise_limit,
+            self.noise_map,
         )
+
+        interferometer.noise_map = vis.VisibilitiesNoiseMap(
+            visibilities_1d=noise_map_limit
+        )
+
         return interferometer
 
 
+class AbstractSettingsMaskedInterferometer(
+    abstract_dataset.AbstractSettingsMaskedDataset
+):
+    def __init__(
+        self,
+        grid_class=grids.Grid,
+        grid_inversion_class=grids.Grid,
+        sub_size=2,
+        fractional_accuracy=0.9999,
+        sub_steps=None,
+        pixel_scales_interp=None,
+        signal_to_noise_limit=None,
+        transformer_class=trans.TransformerNUFFT,
+    ):
+        """
+          The lens dataset is the collection of data_type (image, noise-map), a mask, grid, convolver \
+          and other utilities that are used for modeling and fitting an image of a strong lens.
+
+          Whilst the image, noise-map, etc. are loaded in 2D, the lens dataset creates reduced 1D arrays of each \
+          for lens calculations.
+
+          Parameters
+          ----------
+        grid_class : ag.Grid
+            The type of grid used to create the image from the *Galaxy* and *Plane*. The options are *Grid*,
+            *GridIterate* and *GridInterpolate* (see the *Grids* documentation for a description of these options).
+        grid_inversion_class : ag.Grid
+            The type of grid used to create the grid that maps the *Inversion* source pixels to the data's image-pixels.
+            The options are *Grid*, *GridIterate* and *GridInterpolate* (see the *Grids* documentation for a
+            description of these options).
+        sub_size : int
+            If the grid and / or grid_inversion use a *Grid*, this sets the sub-size used by the *Grid*.
+        fractional_accuracy : float
+            If the grid and / or grid_inversion use a *GridIterate*, this sets the fractional accuracy it
+            uses when evaluating functions.
+        sub_steps : [int]
+            If the grid and / or grid_inversion use a *GridIterate*, this sets the steps the sub-size is increased by
+            to meet the fractional accuracy when evaluating functions.
+        pixel_scales_interp : float or (float, float)
+            If the grid and / or grid_inversion use a *GridInterpolate*, this sets the resolution of the interpolation
+            grid.
+        signal_to_noise_limit : float
+            If input, the dataset's noise-map is rescaled such that no pixel has a signal-to-noise above the
+            signa to noise limit.
+          """
+
+        super().__init__(
+            grid_class=grid_class,
+            grid_inversion_class=grid_inversion_class,
+            sub_size=sub_size,
+            fractional_accuracy=fractional_accuracy,
+            sub_steps=sub_steps,
+            pixel_scales_interp=pixel_scales_interp,
+            signal_to_noise_limit=signal_to_noise_limit,
+        )
+
+        self.transformer_class = transformer_class
+
+    @property
+    def tag_no_inversion(self):
+        return (
+            self.grid_tag_no_inversion
+            + self.transformer_tag
+            + self.signal_to_noise_limit_tag
+        )
+
+    @property
+    def tag_with_inversion(self):
+        return (
+            self.grid_tag_with_inversion
+            + self.transformer_tag
+            + self.signal_to_noise_limit_tag
+        )
+
+    @property
+    def transformer_tag(self):
+        """Generate an image psf shape tag, to customize phase names based on size of the image PSF that the original PSF \
+        is trimmed to for faster run times.
+
+        This changes the phase settings folder as follows:
+
+        image_psf_shape = 1 -> settings
+        image_psf_shape = 2 -> settings_image_psf_shape_2
+        image_psf_shape = 2 -> settings_image_psf_shape_2
+        """
+        if self.transformer_class is None:
+            return ""
+        return "__" + conf.instance.tag.get(
+            "interferometer", self.transformer_class.__name__
+        )
+
+
 class AbstractMaskedInterferometer(abstract_dataset.AbstractMaskedDataset):
     def __init__(
         self,
         interferometer,
         visibilities_mask,
         real_space_mask,
-        grid_class=grids.GridIterate,
-        grid_inversion_class=grids.Grid,
-        fractional_accuracy=0.9999,
-        sub_steps=None,
-        pixel_scales_interp=None,
-        transformer_class=trans.TransformerNUFFT,
-        primary_beam_shape_2d=None,
-        inversion_pixel_limit=None,
-        inversion_uses_border=True,
-        renormalize_primary_beam=True,
+        settings=AbstractSettingsMaskedInterferometer(),
     ):
         """
-        The lens dataset is the collection of data_type (image, noise-map, primary_beam), a mask, grid, convolver \
+        The lens dataset is the collection of data_type (image, noise-map), a mask, grid, convolver \
         and other utilities that are used for modeling and fitting an image of a strong lens.
 
         Whilst the image, noise-map, etc. are loaded in 2D, the lens dataset creates reduced 1D arrays of each \
@@ -91,72 +176,21 @@ class AbstractMaskedInterferometer(abstract_dataset.AbstractMaskedDataset):
         Parameters
         ----------
         imaging: im.Imaging
-            The imaging data_type all in 2D (the image, noise-map, primary_beam, etc.)
+            The imaging data_type all in 2D (the image, noise-map, etc.)
         real_space_mask: msk.Mask
             The 2D mask that is applied to the image.
-        sub_size : int
-            The size of the sub-grid used for each lens SubGrid. E.g. a value of 2 grid each image-pixel on a 2x2 \
-            sub-grid.
-        primary_beam_shape_2d : (int, int)
-            The shape of the primary_beam used for convolving model image generated using analytic light profiles. A smaller \
-            shape will trim the primary_beam relative to the input image primary_beam, giving a faster analysis run-time.
-        positions : [[]]
-            Lists of image-pixel coordinates (arc-seconds) that mappers close to one another in the source-plane(s), \
-            used to speed up the non-linear sampling.
-        pixel_scales_interp : float
-            If *True*, expensive to compute mass profile deflection angles will be computed on a sparse grid and \
-            interpolated to the grid, sub and blurring grids.
-        inversion_pixel_limit : int or None
-            The maximum number of pixels that can be used by an inversion, with the limit placed primarily to speed \
-            up run.
         """
 
         super().__init__(
-            dataset=interferometer,
-            mask=real_space_mask,
-            grid_class=grid_class,
-            grid_inversion_class=grid_inversion_class,
-            fractional_accuracy=fractional_accuracy,
-            sub_steps=sub_steps,
-            pixel_scales_interp=pixel_scales_interp,
-            inversion_pixel_limit=inversion_pixel_limit,
-            inversion_uses_border=inversion_uses_border,
+            dataset=interferometer, mask=real_space_mask, settings=settings
         )
 
-        if self.interferometer.primary_beam is None:
-            self.primary_beam_shape_2d = None
-        elif (
-            primary_beam_shape_2d is None
-            and self.interferometer.primary_beam is not None
-        ):
-            self.primary_beam_shape_2d = self.interferometer.primary_beam.shape_2d
-        else:
-            self.primary_beam_shape_2d = primary_beam_shape_2d
-
-        if self.primary_beam_shape_2d is not None:
-            self.primary_beam = kernel.Kernel.manual_2d(
-                array=interferometer.primary_beam.resized_from_new_shape(
-                    new_shape=self.primary_beam_shape_2d
-                ).in_2d,
-                renormalize=renormalize_primary_beam,
-            )
-
-        if transformer_class is not trans.TransformerNUFFTLops:
-            self.transformer = transformer_class(
-                uv_wavelengths=interferometer.uv_wavelengths,
-                real_space_mask=real_space_mask,
-            )
-        else:
-            self.transformer = transformer_class(
-                uv_wavelengths=interferometer.uv_wavelengths,
-                real_space_mask=real_space_mask,
-                dims_fft=interferometer.visibilities.shape[0],
-            )
+        self.transformer = self.settings.transformer_class(
+            uv_wavelengths=interferometer.uv_wavelengths,
+            real_space_mask=real_space_mask,
+        )
 
         self.visibilities = interferometer.visibilities
-        self.visibilities_complex = np.apply_along_axis(
-            lambda args: [complex(*args)], 1, interferometer.visibilities
-        )
         self.noise_map = interferometer.noise_map
         self.visibilities_mask = visibilities_mask
 
@@ -195,8 +229,6 @@ class AbstractSimulatorInterferometer:
         exposure_time_map,
         background_sky_map=None,
         transformer_class=trans.TransformerDFT,
-        primary_beam=None,
-        renormalize_primary_beam=True,
         noise_sigma=0.1,
         noise_if_add_noise_false=0.1,
         noise_seed=-1,
@@ -223,11 +255,6 @@ class AbstractSimulatorInterferometer:
         self.exposure_time_map = exposure_time_map
         self.background_sky_map = background_sky_map
         self.transformer_class = transformer_class
-
-        if primary_beam is not None and renormalize_primary_beam:
-            primary_beam = primary_beam.renormalized
-
-        self.primary_beam = primary_beam
         self.noise_sigma = noise_sigma
         self.noise_if_add_noise_false = noise_if_add_noise_false
         self.noise_seed = noise_seed
@@ -294,7 +321,6 @@ class AbstractSimulatorInterferometer:
             visibilities=visibilities,
             noise_map=noise_map,
             uv_wavelengths=transformer.uv_wavelengths,
-            primary_beam=self.primary_beam,
             name=name,
         )
 
@@ -309,8 +335,6 @@ class Interferometer(AbstractInterferometer):
         visibilities_hdu=0,
         noise_map_hdu=0,
         uv_wavelengths_hdu=0,
-        primary_beam_path=None,
-        primary_beam_hdu=0,
         positions_path=None,
     ):
         """Factory for loading the interferometer data_type from .fits files, as well as computing properties like the noise-map,
@@ -327,7 +351,7 @@ class Interferometer(AbstractInterferometer):
             file_path=visibilities_path, hdu=visibilities_hdu
         )
 
-        noise_map = aa.Visibilities.from_fits(
+        noise_map = aa.VisibilitiesNoiseMap.from_fits(
             file_path=noise_map_path, hdu=noise_map_hdu
         )
 
@@ -335,13 +359,6 @@ class Interferometer(AbstractInterferometer):
             file_path=uv_wavelengths_path, hdu=uv_wavelengths_hdu
         )
 
-        if primary_beam_path is not None:
-            primary_beam = aa.Kernel.from_fits(
-                file_path=primary_beam_path, hdu=primary_beam_hdu, renormalize=True
-            )
-        else:
-            primary_beam = None
-
         if positions_path is not None:
 
             positions = grids.GridCoordinates.from_file(file_path=positions_path)
@@ -352,7 +369,6 @@ class Interferometer(AbstractInterferometer):
 
         return Interferometer(
             visibilities=visibilities,
-            primary_beam=primary_beam,
             noise_map=noise_map,
             uv_wavelengths=uv_wavelengths,
             positions=positions,
@@ -362,16 +378,10 @@ class Interferometer(AbstractInterferometer):
         self,
         visibilities_path=None,
         noise_map_path=None,
-        primary_beam_path=None,
         uv_wavelengths_path=None,
         overwrite=False,
     ):
 
-        if primary_beam_path is not None:
-            self.primary_beam.output_to_fits(
-                file_path=primary_beam_path, overwrite=overwrite
-            )
-
         if visibilities_path is not None:
             self.visibilities.output_to_fits(
                 file_path=visibilities_path, overwrite=overwrite
@@ -388,6 +398,11 @@ class Interferometer(AbstractInterferometer):
             )
 
 
+class SettingsMaskedInterferometer(AbstractSettingsMaskedInterferometer):
+
+    pass
+
+
 class MaskedInterferometer(AbstractMaskedInterferometer):
 
     pass
